--
-- bridgeable
-- Specialization for bridgeable hydraulic functionality
--                and change selectable carrier trailer
--
-- by Blacky_BPG
-- 
-- version: 1.0.0 - 15.04.2014
--
-- free for noncommerical-usage
--

bridgeable = {};

function bridgeable.prerequisitesPresent(specializations)
    return true;
end;

function bridgeable:load(xmlFile)

	self.myAttacherVehicle = nil;
	self.myAttacherJoint = nil;
	self.myBridge = nil;
	self.mySelfIsCarrier = Utils.getNoNil(getXMLBool(xmlFile, "vehicle.hydraulicTipping0#isCarrier"),false);

	local hydCyl1 = getXMLString(xmlFile, "vehicle.hydraulicTipping1#index");
	if hydCyl1 ~= nil then
		local hydCyl1Obj = Utils.indexToObject(self.components, hydCyl1);
		if hydCyl1Obj ~= nil then
			self.myHydraulic1 = hydCyl1Obj;
		end;
	end;

	local hydCyl2 = getXMLString(xmlFile, "vehicle.hydraulicTipping2#index");
	if hydCyl2 ~= nil then
		local hydCyl2Obj = Utils.indexToObject(self.components, hydCyl2);
		if hydCyl2Obj ~= nil then
			self.myHydraulic2 = hydCyl2Obj;
		end;
	end;

	local hydCyl3 = getXMLString(xmlFile, "vehicle.hydraulicTipping3#index");
	if hydCyl3 ~= nil then
		local hydCyl3Obj = Utils.indexToObject(self.components, hydCyl3);
		if hydCyl3Obj ~= nil then
			self.myHydraulic3 = hydCyl3Obj;
		end;
	end;
end;

function bridgeable:onAttach(attacherVehicle, jointDescIndex)
	if attacherVehicle ~= nil then
		if not self.mySelfIsCarrier then
			self.myAttacherJoint = jointDescIndex;
			self.myAttacherVehicle = attacherVehicle;
			self.myAttacherVehicle.myBridge = self;
			if self.myHydraulic1 ~= nil then
				setVisibility(self.myHydraulic1, true);
				if attacherVehicle.myHydraulic1 ~= nil then
					setVisibility(attacherVehicle.myHydraulic1, false);
				end;
			end;
			if self.myHydraulic2 ~= nil then
				setVisibility(self.myHydraulic2, true);
				if attacherVehicle.myHydraulic2 ~= nil then
					setVisibility(attacherVehicle.myHydraulic2, false);
				end;
			end;
			if self.myHydraulic3 ~= nil then
				setVisibility(self.myHydraulic3, true);
				if attacherVehicle.myHydraulic3 ~= nil then
					setVisibility(attacherVehicle.myHydraulic3, false);
				end;
			end;
		end;
	end;
end;

function bridgeable:onDetach(attacherVehicle, jointDescIndex)
	if not self.mySelfIsCarrier then
		if self:getToggledFoldDirection() > 0 then
			if self.myAttacherVehicle ~= nil and self.myAttacherJoint ~= nil then
				self.myAttacherVehicle:attachImplement(self,self.myAttacherJoint);
				if self.myAttacherVehicle.attacherVehicle ~= nil then
					self.myAttacherVehicle.attacherVehicle:detachImplementByObject(self.myAttacherVehicle);
				end;
			end;
		else
			if self.myHydraulic1 ~= nil then
				setVisibility(self.myHydraulic1, false);
			end;
			if self.myHydraulic2 ~= nil then
				setVisibility(self.myHydraulic2, false);
			end;
			if self.myHydraulic3 ~= nil then
				setVisibility(self.myHydraulic3, false);
			end;
			if self.myAttacherVehicle ~= nil then
				if self.myAttacherVehicle.myHydraulic1 ~= nil then
					setVisibility(self.myAttacherVehicle.myHydraulic1, true);
				end;
				if self.myAttacherVehicle.myHydraulic2 ~= nil then
					setVisibility(self.myAttacherVehicle.myHydraulic2, true);
				end;
				if self.myAttacherVehicle.myHydraulic3 ~= nil then
					setVisibility(self.myAttacherVehicle.myHydraulic3, true);
				end;
				self.myAttacherVehicle = nil;
			end;
		end;
	end;
end;

function bridgeable:updateTick(dt)
	if not self.mySelfIsCarrier then
		if self.myAttacherVehicle ~= nil then
			if self:getToggledFoldDirection() > 0 then
				if self.myAttacherVehicle.isSelectable then
					self.myAttacherVehicle.isSelectable = false;
				end;
			else
				if not self.myAttacherVehicle.isSelectable then
					self.myAttacherVehicle.isSelectable = true;
				end;
			end;
		end;
	end;
end;

function bridgeable:preDelete()
	self.myAttacherVehicle = nil;
	self.myAttacherJoint = nil;
	self.isSelectable = true;
	if self.myBridge ~= nil then
		self.myBridge.myAttacherVehicle = nil;
		self.myBridge.myAttacherJoint = nil;
	end;
end;

function bridgeable:delete()
	self.myAttacherVehicle = nil;
	self.myAttacherJoint = nil;
	self.isSelectable = true;
	if self.myBridge ~= nil then
		self.myBridge.myAttacherVehicle = nil;
		self.myBridge.myAttacherJoint = nil;
	end;
end;

function bridgeable:mouseEvent(posX, posY, isDown, isUp, button)
end;

function bridgeable:keyEvent(unicode, sym, modifier, isDown)
end;

function bridgeable:update(dt)
end;

function bridgeable:draw()
end;

function bridgeable:loadFromAttributesAndNodes(xmlFile, key, resetVehicles)
	if resetVehicles then
		self.myAttacherVehicle = nil;
		self.myAttacherJoint = nil;
		self.isSelectable = true;
		if self.myBridge ~= nil then
			self.myBridge.myAttacherVehicle = nil;
			self.myBridge.myAttacherJoint = nil;
		end;
	end;
	return BaseMission.VEHICLE_LOAD_OK;
end;

function bridgeable:getSaveAttributesAndNodes(nodeIdent)	
    return nil, nil;
end;
